==> r-mail-1.0.0.zip: r-mail-1.0.0/gestion_messages/supprimer_message.php <==
<?

session_start ();

$serveur="{".$serveur_mail.":$port_connexion"."}$nom_boite";

$connect_imap=@imap_open($serveur,"$login","$password")
or die ('impossible de se connecter au serveur');

//On ralise des suites logiques pour dterminer les message 
//effacer par imap_delete.

$suite_logique=array();
$stock=array();

if (count ($z)==0) {
exit ("<center><a href=\"sujets.php\">Merci de cocher les messages  supprimer</a></center>".
"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
"<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>\n</td></tr>\n</table>\n");
}

if (count ($z)==0) {
exit ("<center>Merci de cocher les messages  supprimer</center>".
"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
"<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>\n</td></tr>\n</table>\n");
}

foreach ($z as $suite) {
	
	if ($suite!=1 && count ($stock)!=0 && max ($stock)+1==$suite && end($z)!=$suite) {
		array_push ($suite_logique, $suite-1, $suite);
		array_shift ($stock);
	} else {
		array_push ($stock, $suite);
		if (!isset ($fait) && count ($suite_logique)!=0) {
			$fait=1;
				foreach ($suite_logique as $suppr) {
				if (imap_delete ($connect_imap, $suppr)!=true) {
				exit ("<center>Les suppressions n'ont pas fonctionnes</center>".
				"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>\n</td></tr>\n</table>\n");
				}
			}
			array_splice ($suite_logique, 0);
		} elseif (count ($stock) >1) {
			if (imap_delete ($connect_imap, $stock[0])!=true) {
			exit ("center>La suppression du message n'a pas fonctionne</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>\n</td></tr>\n</table>\n");
			}
			array_shift ($stock);
			unset ($fait);
		} else {
			unset ($fait);
		}
	}
	
	if (end($z)==$suite) {
		if (count ($suite_logique)!=0) {
		$boom=implode ("," , $suite_logique);
			foreach ($suite_logique as $suppr) {
			if (imap_delete ($connect_imap, $suppr)!=true) {
			exit ("<center>Les dernires suppressions n'ont pas fonctionnes</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>\n</td></tr>\n</table>\n");
			}
			}
		array_splice ($suite_logique, 0);
		}
	if (count ($stock)!=0) {
		$boom=implode ("," , $stock);
			foreach ($stock as $suppr2) {
			if (imap_delete ($connect_imap, $suppr2)!=true) {
			exit ("<center>La dernire suppression n'a pas fonctionne</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>\n</td></tr>\n</table>\n");
			}
			}
		array_splice ($stock, 0);
		}
	}

}

imap_close ($connect_imap);

?>

==> r-mail-1.0.2.zip: r-mail.1.0.2/gestion_messages/supprimer_message.php <==
<?

include 'langage.php';

$serveur="{".$_SESSION ["serveur_mail"].":".$_SESSION ["port_connexion"]."}".$_POST ["nom_boite"];

$connect_imap=@imap_open($serveur,$_SESSION ["login"],$_SESSION ["password"])
or die ($page_supprimer_message[$_SESSION ["lang"]][0]);

//On ralise des suites logiques pour dterminer les message 
//effacer par imap_delete.

$suite_logique=array();
$stock=array();

if (!isset ($_POST ["z"])) {
$_POST ["z"] = NULL;
} 
	
if (count ($_POST ["z"])==0 && !isset ($_POST ["coche_tout"])) {
exit ("<center><a href=\"sujets.php?boite=".$boite."\">".$page_supprimer_message[$_SESSION ["lang"]][1]."</a></center>".
"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
"<font size=5><b><u>R-MAIL</u></b></font>\n</td></tr>\n</table>\n");
}

foreach ($_POST ["z"] as $suite) {
	
	if ($suite!=1 && count ($stock)!=0 && max ($stock)+1==$suite && end($_POST ["z"])!=$suite) {
		array_push ($suite_logique, $suite-1, $suite);
		array_shift ($stock);
	} else {
		array_push ($stock, $suite);
		if (!isset ($fait) && count ($suite_logique)!=0) {
			$fait=1;
				foreach ($suite_logique as $suppr) {
				if (imap_delete ($connect_imap, $suppr)!=true) {
				exit ("<center>".$page_supprimer_message[$_SESSION ["lang"]][2]."</center>".
				"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL</u></b></font>\n</td></tr>\n</table>\n");
				}
			}
			array_splice ($suite_logique, 0);
		} elseif (count ($stock) >1) {
			if (imap_delete ($connect_imap, $stock[0])!=true) {
			exit ("center>".$page_supprimer_message[$_SESSION ["lang"]][3]."</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL</u></b></font>\n</td></tr>\n</table>\n");
			}
			array_shift ($stock);
			unset ($fait);
		} else {
			unset ($fait);
		}
	}
	
	if (end($_POST ["z"])==$suite) {
		if (count ($suite_logique)!=0) {
		$boom=implode ("," , $suite_logique);
			foreach ($suite_logique as $suppr) {
			if (imap_delete ($connect_imap, $suppr)!=true) {
			exit ("<center>".$page_supprimer_message[$_SESSION ["lang"]][4]."</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL</u></b></font>\n</td></tr>\n</table>\n");
			}
			}
		array_splice ($suite_logique, 0);
		}
	if (count ($stock)!=0) {
		$boom=implode ("," , $stock);
			foreach ($stock as $suppr2) {
			if (imap_delete ($connect_imap, $suppr2)!=true) {
			exit ("<center>".$page_supprimer_message[$_SESSION ["lang"]][5]."</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL</u></b></font>\n</td></tr>\n</table>\n");
			}
			}
		array_splice ($stock, 0);
		}
	}

}

imap_close ($connect_imap);

?>
